'use client';

import { Button, ButtonProps } from '@mui/material';
import { motion } from 'framer-motion';

interface ElegantButtonProps extends Omit<ButtonProps, 'variant'> {
  variant?: 'primary' | 'secondary' | 'tertiary';
}

export default function ElegantButton({ 
  children, 
  variant = 'primary',
  sx,
  ...props 
}: ElegantButtonProps) {
  const getVariantStyles = () => {
    switch (variant) {
      case 'primary':
        return {
          backgroundColor: '#007AFF',
          color: 'white',
          '&:hover': {
            backgroundColor: '#0062cc',
            transform: 'translateY(-2px)',
            boxShadow: '0 4px 12px rgba(0, 122, 255, 0.3)',
          },
        };
      case 'secondary':
        return {
          backgroundColor: 'transparent',
          color: '#007AFF',
          border: '1px solid #007AFF',
          '&:hover': {
            backgroundColor: 'rgba(0, 122, 255, 0.05)',
            transform: 'translateY(-2px)',
          },
        };
      case 'tertiary':
        return {
          backgroundColor: 'transparent',
          color: '#007AFF',
          '&:hover': {
            backgroundColor: 'rgba(0, 122, 255, 0.05)',
          },
        };
      default:
        return {};
    }
  };

  return (
    <motion.div
      whileHover={{ scale: 1.02 }}
      whileTap={{ scale: 0.98 }}
    >
      <Button
        {...props}
        sx={{
          textTransform: 'none',
          fontWeight: 500,
          borderRadius: '12px',
          transition: 'all 0.3s ease',
          position: 'relative',
          overflow: 'hidden',
          '&::before': {
            content: '""',
            position: 'absolute',
            top: 0,
            left: 0,
            right: 0,
            bottom: 0,
            background: 'linear-gradient(45deg, transparent, rgba(255,255,255,0.1), transparent)',
            transform: 'translateX(-100%)',
            transition: 'transform 0.6s ease',
          },
          '&:hover::before': {
            transform: 'translateX(100%)',
          },
          ...getVariantStyles(),
          ...sx,
        }}
      >
        {children}
      </Button>
    </motion.div>
  );
} 