'use client';

import { AppBar, Toolbar, Button, Typography, Box, IconButton, Menu, MenuItem, useMediaQuery, useTheme } from '@mui/material';
import Link from 'next/link';
import MenuIcon from '@mui/icons-material/Menu';
import WorkOutlineIcon from '@mui/icons-material/WorkOutline';
import BusinessCenterIcon from '@mui/icons-material/BusinessCenter';
import SchoolIcon from '@mui/icons-material/School';
import { useState } from 'react';

export default function Header() {
  const theme = useTheme();
  const isMobile = useMediaQuery(theme.breakpoints.down('md'));
  const [mobileMenuAnchor, setMobileMenuAnchor] = useState<null | HTMLElement>(null);

  const handleMobileMenuOpen = (event: React.MouseEvent<HTMLElement>) => {
    setMobileMenuAnchor(event.currentTarget);
  };

  const handleMobileMenuClose = () => {
    setMobileMenuAnchor(null);
  };

  const navItems = [
    { label: 'Offres', icon: <WorkOutlineIcon />, href: '/offres' },
    { label: 'Entreprises', icon: <BusinessCenterIcon />, href: '/entreprises' },
    { label: 'Formations', icon: <SchoolIcon />, href: '/formations' },
  ];

  return (
    <AppBar 
      position="static" 
      elevation={0}
      sx={{ 
        backgroundColor: 'white',
        color: 'black',
        borderBottom: '1px solid #F5F5F7'
      }}
    >
      <Toolbar sx={{ 
        justifyContent: 'space-between',
        maxWidth: '1200px',
        width: '100%',
        mx: 'auto',
        px: { xs: 2, md: 4 }
      }}>
        <Box sx={{ display: 'flex', alignItems: 'center', gap: 4 }}>
          <Typography 
            variant="h6" 
            component={Link} 
            href="/"
            sx={{ 
              textDecoration: 'none',
              color: 'black',
              fontWeight: 600,
              display: 'flex',
              alignItems: 'center',
              gap: 1
            }}
          >
            JobMatch
          </Typography>

          {!isMobile && (
            <Box sx={{ display: 'flex', gap: 2 }}>
              {navItems.map((item) => (
                <Button
                  key={item.label}
                  component={Link}
                  href={item.href}
                  startIcon={item.icon}
                  sx={{ 
                    color: '#1D1D1F',
                    textTransform: 'none',
                    fontWeight: 500,
                    '&:hover': {
                      color: '#007AFF',
                      backgroundColor: 'transparent'
                    }
                  }}
                >
                  {item.label}
                </Button>
              ))}
            </Box>
          )}
        </Box>
        
        <Box sx={{ display: 'flex', alignItems: 'center', gap: 2 }}>
          {isMobile ? (
            <>
              <IconButton
                edge="end"
                color="inherit"
                aria-label="menu"
                onClick={handleMobileMenuOpen}
                sx={{ color: '#1D1D1F' }}
              >
                <MenuIcon />
              </IconButton>
              <Menu
                anchorEl={mobileMenuAnchor}
                open={Boolean(mobileMenuAnchor)}
                onClose={handleMobileMenuClose}
                sx={{
                  '& .MuiPaper-root': {
                    borderRadius: '12px',
                    boxShadow: '0 4px 12px rgba(0,0,0,0.1)',
                  }
                }}
              >
                {navItems.map((item) => (
                  <MenuItem
                    key={item.label}
                    component={Link}
                    href={item.href}
                    onClick={handleMobileMenuClose}
                    sx={{
                      py: 1,
                      px: 2,
                      '&:hover': {
                        backgroundColor: 'rgba(0, 122, 255, 0.05)',
                      }
                    }}
                  >
                    <Box sx={{ display: 'flex', alignItems: 'center', gap: 1 }}>
                      {item.icon}
                      {item.label}
                    </Box>
                  </MenuItem>
                ))}
                <MenuItem
                  component={Link}
                  href="/signup"
                  onClick={handleMobileMenuClose}
                  sx={{
                    py: 1,
                    px: 2,
                    color: '#007AFF',
                    '&:hover': {
                      backgroundColor: 'rgba(0, 122, 255, 0.05)',
                    }
                  }}
                >
                  Inscription
                </MenuItem>
                <MenuItem
                  component={Link}
                  href="/login"
                  onClick={handleMobileMenuClose}
                  sx={{
                    py: 1,
                    px: 2,
                    color: '#007AFF',
                    '&:hover': {
                      backgroundColor: 'rgba(0, 122, 255, 0.05)',
                    }
                  }}
                >
                  Connexion
                </MenuItem>
              </Menu>
            </>
          ) : (
            <>
              <Button 
                component={Link}
                href="/signup"
                sx={{ 
                  color: '#007AFF',
                  textTransform: 'none',
                  fontWeight: 500,
                  '&:hover': {
                    backgroundColor: 'rgba(0, 122, 255, 0.05)',
                  }
                }}
              >
                Inscription
              </Button>
              <Button 
                component={Link}
                href="/login"
                variant="contained"
                sx={{ 
                  backgroundColor: '#007AFF',
                  textTransform: 'none',
                  fontWeight: 500,
                  borderRadius: '8px',
                  '&:hover': {
                    backgroundColor: '#0062cc',
                    transform: 'translateY(-1px)',
                    boxShadow: '0 4px 12px rgba(0, 122, 255, 0.2)',
                  }
                }}
              >
                Connexion
              </Button>
            </>
          )}
        </Box>
      </Toolbar>
    </AppBar>
  );
} 