'use client';

import { useState } from 'react';
import { useRouter } from 'next/navigation';
import { Box, Container, Typography, TextField, Button, Link as MuiLink } from '@mui/material';
import Link from 'next/link';
import { supabase } from '@/lib/supabase';
import { useAuthStore } from '@/store/auth';

export default function Login() {
  const router = useRouter();
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState<string | null>(null);
  const [isLoading, setIsLoading] = useState(false);
  const { setUser } = useAuthStore();

  const handleLogin = async (e: React.FormEvent) => {
    e.preventDefault();
    setError(null);
    setIsLoading(true);

    try {
      const { data, error } = await supabase.auth.signInWithPassword({
        email,
        password,
      });

      if (error) throw error;

      setUser(data.user);
      router.push('/profile');
    } catch (error) {
      setError('Email ou mot de passe incorrect');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <Container maxWidth="sm">
      <Box
        sx={{
          minHeight: 'calc(100vh - 64px)',
          display: 'flex',
          flexDirection: 'column',
          justifyContent: 'center',
          py: 8,
        }}
      >
        <Typography
          variant="h4"
          component="h1"
          sx={{
            mb: 4,
            fontWeight: 700,
            textAlign: 'center',
          }}
        >
          Connexion
        </Typography>

        <Box
          component="form"
          onSubmit={handleLogin}
          sx={{
            display: 'flex',
            flexDirection: 'column',
            gap: 3,
            p: 4,
            borderRadius: '16px',
            backgroundColor: 'white',
            boxShadow: '0 4px 12px rgba(0,0,0,0.05)',
          }}
        >
          <TextField
            label="Email"
            type="email"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
            required
            fullWidth
            error={!!error}
            helperText={error}
          />

          <TextField
            label="Mot de passe"
            type="password"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
            required
            fullWidth
          />

          <Button
            type="submit"
            variant="contained"
            size="large"
            disabled={isLoading}
            sx={{
              backgroundColor: '#007AFF',
              '&:hover': {
                backgroundColor: '#0062cc',
              },
            }}
          >
            {isLoading ? 'Connexion...' : 'Se connecter'}
          </Button>

          <Typography
            variant="body2"
            sx={{
              textAlign: 'center',
              color: '#86868B',
            }}
          >
            Pas encore de compte ?{' '}
            <MuiLink
              component={Link}
              href="/signup"
              sx={{
                color: '#007AFF',
                textDecoration: 'none',
                '&:hover': {
                  textDecoration: 'underline',
                },
              }}
            >
              Créer un compte
            </MuiLink>
          </Typography>
        </Box>
      </Box>
    </Container>
  );
} 